# pyogt [![Build Status](https://travis-ci.com/claha/pyogt.svg?branch=master)](https://travis-ci.com/claha/pyogt) [![Coverage Status](https://coveralls.io/repos/github/claha/pyogt/badge.svg?branch=master)](https://coveralls.io/github/claha/pyogt?branch=master)
Retrieve departure information from OstgotaTrafiken
